pub struct Claude { /* private fields */ }Expand description
Claude API client
Implementations
Sourceimpl Claude
impl Claude
Sourcepub async fn create_chat(&self) -> Result<String>
pub async fn create_chat(&self) -> Result<String>
Create a new chat conversation
Sourcepub async fn delete_chat(&self, chat_id: &str) -> Result<()>
pub async fn delete_chat(&self, chat_id: &str) -> Result<()>
Delete an existing chat conversation
Sourcepub async fn send_message(
&self,
chat_id: &str,
prompt: &str,
attachments: &[Attachment],
) -> Result<String>
pub async fn send_message( &self, chat_id: &str, prompt: &str, attachments: &[Attachment], ) -> Result<String>
Send a message to the chat and return the completion Send a message to the chat with optional attachments and return the completion